NaturalLanguage class

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

entityExtractor(String language) → EntityExtractor
Returns instance of EntityExtractor.
entityModelManager() → EntityModelManager
Returns instance of EntityModelManager.
languageIdentifier({double confidenceThreshold = 0.5}) → LanguageIdentifier
Returns instance of LanguageIdentifier.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onDeviceTranslator({required String sourceLanguage, required String targetLanguage}) → OnDeviceTranslator
Returns instance of OnDeviceTranslator.
smartReply() → SmartReply
Returns instance of SmartReply.
toString() → String
A string representation of this object.
inherited
translateLanguageModelManager() → TranslateLanguageModelManager
Returns instance of TranslateLanguageModelManager.

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance → NaturalLanguage
final

Constants

channel → const MethodChannel