TrackingNumberEntity class

Inheritance

Constructors

TrackingNumberEntity(String string, int _carrier, String _number)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getParcelCarrier() → int
getParcelTrackingNumber() → String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CARRIER_AMAZON → const int
CARRIER_DHL → const int
CARRIER_FEDEX → const int
CARRIER_I_PARCEL → const int
CARRIER_ISRAEL_POST → const int
CARRIER_LASERSHIP → const int
CARRIER_MSC → const int
CARRIER_ONTRAC → const int
CARRIER_SWISS_POST → const int
CARRIER_UNKNOWN → const int
CARRIER_UPS → const int
CARRIER_USPS → const int