BarcodeCalenderEvent class

Class extending over BarcodeValue that models a calender event.

Inheritance

Properties

boundingBox → Rect?
The bounding rectangle of the detected barcode.
finalinherited
description → String?
Description of the event.
final
displayValue → String?
Barcode value in a user-friendly format. This value may be multiline, for example, when line breaks are encoded into the original TEXT barcode value. May include the supplement value.
finalinherited
end → DateTime?
End DateTime of the calender event.
final
format → BarcodeFormat
The format (symbology) of the barcode value.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
location → String?
Location of the event.
final
organizer → String?
A person or the organisation who is organising the event.
final
rawBytes → Uint8List?
Barcode bytes as encoded in the barcode.
finalinherited
rawValue → String?
Barcode value as it was encoded in the barcode.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
start → DateTime?
Start DateTime of the calender event.
final
status → String?
Status of the event -> whether the event is completed or not.
final
summary → String?
A short summary of the event.
final
type → BarcodeType
The format type of the barcode value.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited