BarcodeContactInfo class

Class extending over BarcodeValue that models a contact info.

Inheritance

Properties

addresses → List<BarcodeAddress>
Contact person's addresses.
final
boundingBox → Rect?
The bounding rectangle of the detected barcode.
finalinherited
displayValue → String?
Barcode value in a user-friendly format. This value may be multiline, for example, when line breaks are encoded into the original TEXT barcode value. May include the supplement value.
finalinherited
emails → List<BarcodeEmail>
Email addresses of the contact person.
final
firstName → String?
First name of the contact person.
final
format → BarcodeFormat
The format (symbology) of the barcode value.
finalinherited
formattedName → String?
Properly formatted name of the person.
final
hashCode → int
The hash code for this object.
no setterinherited
jobTitle → String?
Job title
final
lastName → String?
Last name of the person.
final
middleName → String?
Middle name of the person.
final
organizationName → String?
Organization of the contact person.
final
phoneNumbers → List<BarcodePhone>
Phone numbers of the contact person.
final
prefix → String?
Name prefix
final
pronunciation → String?
Name pronunciation
final
rawBytes → Uint8List?
Barcode bytes as encoded in the barcode.
finalinherited
rawValue → String?
Barcode value as it was encoded in the barcode.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → BarcodeType
The format type of the barcode value.
finalinherited
urls → List<String>
Url's of contact person.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited