BarcodeDriverLicense class

Class extending over BarcodeValue that models a driver's licence cars.

Inheritance

Properties

addressCity → String?
City of holder's address.
final
addressState → String?
State of the holder's address.
final
addressStreet → String?
Street of the holder's address.
final
addressZip → String?
Zip code code of the holder's address.
final
birthDate → String?
Birth date of the card holder.
final
boundingBox → Rect?
The bounding rectangle of the detected barcode.
finalinherited
country → String?
Country of the holder.
final
displayValue → String?
Barcode value in a user-friendly format. This value may be multiline, for example, when line breaks are encoded into the original TEXT barcode value. May include the supplement value.
finalinherited
expiryDate → String?
Expiry date of the license.
final
firstName → String?
First name of the holder.
final
format → BarcodeFormat
The format (symbology) of the barcode value.
finalinherited
gender → String?
Gender of the holder.
final
hashCode → int
The hash code for this object.
no setterinherited
issueDate → String?
Date on which the license was issued.
final
lastName → String?
Last name of the holder.
final
licenseNumber → String?
Driver license ID.
final
rawBytes → Uint8List?
Barcode bytes as encoded in the barcode.
finalinherited
rawValue → String?
Barcode value as it was encoded in the barcode.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → BarcodeType
The format type of the barcode value.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited