BarcodeEmail class

A email message.

Inheritance

Properties

address → String?
Email address of sender.
final
body → String?
Body of the email.
final
boundingBox → Rect?
The bounding rectangle of the detected barcode.
finalinherited
displayValue → String?
Barcode value in a user-friendly format. This value may be multiline, for example, when line breaks are encoded into the original TEXT barcode value. May include the supplement value.
finalinherited
emailType → BarcodeEmailType?
Type of the email sent.
final
format → BarcodeFormat
The format (symbology) of the barcode value.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
rawBytes → Uint8List?
Barcode bytes as encoded in the barcode.
finalinherited
rawValue → String?
Barcode value as it was encoded in the barcode.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subject → String?
Subject of email.
final
type → BarcodeType
The format type of the barcode value.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited