BarcodeGeo class

Class extending over BarcodeValue that represents a geolocation.

Inheritance

Properties

boundingBox → Rect?
The bounding rectangle of the detected barcode.
finalinherited
displayValue → String?
Barcode value in a user-friendly format. This value may be multiline, for example, when line breaks are encoded into the original TEXT barcode value. May include the supplement value.
finalinherited
format → BarcodeFormat
The format (symbology) of the barcode value.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
latitude → double?
Latitude co-ordinates of the location.
final
longitude → double?
/ Longitude co-ordinates of the location.
final
rawBytes → Uint8List?
Barcode bytes as encoded in the barcode.
finalinherited
rawValue → String?
Barcode value as it was encoded in the barcode.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → BarcodeType
The format type of the barcode value.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited