BarcodeScanner class

Class to scan the barcode in InputImage Creating an instance of BarcodeScanner

BarcodeScanner barcodeScanner = GoogleMlKit.instance.barcodeScanner(List of Barcode formats (optional));

Constructors

BarcodeScanner({List<BarcodeFormat>? formats})

Properties

barcodeFormats → List<BarcodeFormat>
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() → Future<void>
To close the instance of barcodeScanner.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
processImage(InputImage inputImage) → Future<List<Barcode>>
Function to process the InputImage and returns a list of Barcode
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited