BarcodeUrl class

Class to store url info of the bookmark obtained from a barcode.

Inheritance

Properties

boundingBox → Rect?
The bounding rectangle of the detected barcode.
finalinherited
displayValue → String?
Barcode value in a user-friendly format. This value may be multiline, for example, when line breaks are encoded into the original TEXT barcode value. May include the supplement value.
finalinherited
format → BarcodeFormat
The format (symbology) of the barcode value.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
rawBytes → Uint8List?
Barcode bytes as encoded in the barcode.
finalinherited
rawValue → String?
Barcode value as it was encoded in the barcode.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title → String?
Title of the bookmark.
final
type → BarcodeType
The format type of the barcode value.
finalinherited
url → String?
String having the url address of bookmark.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited