CustomImageLabelerOptions class

To create ImageLabeler that processes image based on the custom tflite model provided by user.

Implemented types

Constructors

CustomImageLabelerOptions({double confidenceThreshold = 0.5, required CustomLocalModel customModel, required String customModelPath, int maxCount = 5})
Constructor to create an instance of CustomImageLabelerOptions

Properties

confidenceThreshold → double
The minimum confidence(probability) a label should have to been returned in the result. Default value is set 0.5
final
customModel → CustomLocalModel
Indicates the location of custom model.CustomLocalModel.asset implies the model is stored in assets folder of android module. This is ignored in iOS
final
customModelPath → String
Path where your custom model is stores.
final
hashCode → int
The hash code for this object.
no setterinherited
labelerType → String
Indicates that it uses custom tflite model.
final
maxCount → int
Max number of results detector will return This is ignored in iOS
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited