CustomRemoteLabelerOption class

Implemented types

Constructors

CustomRemoteLabelerOption({required double confidenceThreshold, required String modelName, int maxCount = 5})

Properties

confidenceThreshold → double
The minimum confidence(probability) a label should have to been returned in the result. Default value is set 0.5
final
hashCode → int
The hash code for this object.
no setterinherited
labelerType → String
Indicates that it uses remote firebase models.
final
maxCount → int
Max number of results detector will return This is ignored in iOS
final
modelName → String
Name of the firebase model.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited