DetectedObject class

Class that represents an object detected by ObjectDetector.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getBoundinBox() → Rect
Gets the axis-aligned bounding rectangle of the detected object.
getLabels() → List<Label>
Returns a list of Label when classification is enabled. If disabled it returns an empty list.
getTrackingId() → int?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited