Face class

Represents a face detected by FaceDetector.

Properties

boundingBox → Rect
The axis-aligned bounding rectangle of the detected face.
final
hashCode → int
The hash code for this object.
no setterinherited
headEulerAngleY → double?
The rotation of the face about the vertical axis of the image.
final
headEulerAngleZ → double?
The rotation of the face about the axis pointing out of the image.
final
leftEyeOpenProbability → double?
Probability that the face's left eye is open.
final
rightEyeOpenProbability → double?
Probability that the face's right eye is open.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
smilingProbability → double?
Probability that the face is smiling.
final
trackingId → int?
The tracking ID if the tracking is enabled.
final

Methods

getContour(FaceContourType contour) → FaceContour?
Gets the contour based on the provided FaceContourType.
getLandmark(FaceLandmarkType landmark) → FaceLandmark?
Gets the landmark based on the provided FaceLandmarkType.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited