FaceContour class

Represent a face contour.

Contours of facial features.

Properties

hashCode → int
The hash code for this object.
no setterinherited
positionsList → List<Offset>
Gets a 2D point List for contour positions.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → FaceContourType
The FaceContourType of this contour.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited