FaceDetectorOptions class

Immutable options for configuring features of FaceDetector.

Used to configure features such as classification, face tracking, speed, etc.

Constructors

FaceDetectorOptions({bool enableClassification = false, bool enableLandmarks = false, bool enableContours = false, bool enableTracking = false, double minFaceSize = 0.1, FaceDetectorMode mode = FaceDetectorMode.fast})
Constructor for FaceDetectorOptions.
const

Properties

enableClassification → bool
Whether to run additional classifiers for characterizing attributes.
final
enableContours → bool
Whether to detect FaceContours.
final
enableLandmarks → bool
Whether to detect FaceLandmarks.
final
enableTracking → bool
Whether to enable face tracking.
final
hashCode → int
The hash code for this object.
no setterinherited
minFaceSize → double
The smallest desired face size.
final
mode → FaceDetectorMode
Option for controlling additional accuracy / speed trade-offs.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited