ImageLabel class

This represents a label detected in image.

Constructors

ImageLabel(dynamic data)

Properties

confidence → double
The confidence(probability) given to label that was identified in image
final
hashCode → int
The hash code for this object.
no setterinherited
index → int
Index of label according to google's label map https://developers.google.com/ml-kit/vision/image-labeling/label-map
final
label → String
Label or title given for detected entity in image
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited