ImageLabelerOptions class

To create ImageLabeler that process image considering google's base model

Implemented types

Constructors

ImageLabelerOptions({double confidenceThreshold = 0.5})
Constructor to create instance of ImageLabelerOptions

Properties

confidenceThreshold → double
The minimum confidence(probability) a label should have to been returned in the result Default value is set 0.5
final
hashCode → int
The hash code for this object.
no setterinherited
labelerType → String
Indicates that it uses google's base model to process images.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited