InputImage class

InputImage is the format Google' Ml kit takes to process the image

Constructors

InputImage.fromBytes({required Uint8List bytes, required InputImageData inputImageData})
Create InputImage using bytes.
factory
InputImage.fromFile(File file)
Create InputImage by passing a file.
factory
InputImage.fromFilePath(String path)
Create InputImage from path of image stored in device.
factory

Properties

bytes → Uint8List?
final
filePath → String?
final
hashCode → int
The hash code for this object.
no setterinherited
imageType → String
final
inputImageData → InputImageData?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited