ObjectDetectorOptions class

Options to configure the detector while using with base model.

Inheritance

Constructors

ObjectDetectorOptions({bool classifyObjects = false, bool trackMutipleObjects = false})
Constructor for ObjectDetectorOptions

Properties

classifyObjects → bool
Determines whether to coarsely classify detected objects.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
trackMutipleObjects → bool
Determines whether to track objects or not.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited