PoseDetectorOptions class

PoseDetectorOptions determines the parameters on which PoseDetector works

Constructors

PoseDetectorOptions({PoseDetectionModel model = PoseDetectionModel.base, PoseDetectionMode mode = PoseDetectionMode.streamImage})

Properties

hashCode → int
The hash code for this object.
no setterinherited
mode → PoseDetectionMode
enum PoseDetectionMode, currently only static supported.
final
model → PoseDetectionModel
enum PoseDetectionModel default is set to Base Pose Detector Model.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited