RecognisedText class

Class that gives the detected text. Recognised text hierarchy. Recognised Text ---> List

Constructors

RecognisedText.fromMap(Map map)
factory

Properties

blocks → List<TextBlock>
All the blocks of text present in image.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
text → String
String containing all the text identified in a image.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited