TextBlock class

Class that has a block or group of words present in part of image.

Constructors

TextBlock.fromMap(Map map)
factory

Properties

cornerPoints → List<Offset>
List of corner points of the rect.
final
hashCode → int
The hash code for this object.
no setterinherited
lines → List<TextLine>
List of sentences.
final
recognizedLanguages → List<String>
List of recognized Latin-based languages in the text block.
final
rect → Rect
Rect outlining boundary of block.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
text → String
Text in the block.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited