TextDetector class

Detector to detect text present in the InputImage provided. It returns RecognisedText which contains the info present in the image.

Creating an instance of TextDetector. TextDetector textDetector = GoogleMlKit.instance.textDetector(); Call the processImage() to process the image.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() → Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
processImage(InputImage inputImage) → Future<RecognisedText>
Function that takes InputImage processes it and returns a RecognisedText object.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited