TextLine class

Class that represents sentence present in a certain block.

Constructors

TextLine.fromMap(Map map)
factory

Properties

cornerPoints → List<Offset>
Corner points of the text line.
final
elements → List<TextElement>
List of text element.
final
hashCode → int
The hash code for this object.
no setterinherited
recognizedLanguages → List<String>
List of recognized Latin-based languages in the text block.
final
rect → Rect
Rect outlining the the text line.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
text → String
Sentence of a block.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited