Vision class

Get instance of the individual api's using instance of Vision For example To get an instance of ImageLabeler ImageLabeler imageLabeler = GoogleMlKit.instance.imageLabeler();

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

barcodeScanner([List<BarcodeFormat>? formatList]) → BarcodeScanner
Returns instance of BarcodeScanner. By default it searches the input image for all BarcodeFormats. To limit the search model to specific BarcodeFormat pass list of BarcodeFormat as argument.
digitalInkRecogniser() → DigitalInkRecogniser
Returns an instance of DigitalInkRecogniser
faceDetector([FaceDetectorOptions? options]) → FaceDetector
Return an instance of FaceDetector.
imageLabeler([dynamic imageLabelerOptions]) → ImageLabeler
Get an instance of ImageLabeler by calling this function imageLabelerOptions if not provided it creates ImageLabeler with ImageLabelerOptions You can provide either CustomImageLabelerOptions to use a custom tflite model Or AutoMLImageLabelerOptions to use auto ml vision model trained by you
languageModelManager() → LanguageModelManager
Creates on instance of LanguageModelManager.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
objectDetector(ObjectDetectorOptionsBase options) → ObjectDetector
Returns an instance of ObjectDetector.
poseDetector({PoseDetectorOptions? poseDetectorOptions}) → PoseDetector
Returns instance of PoseDetector.By default it returns all PoseLandmark available in image To limit the result to specific PoseLandmark pass list of PoseLandmark's a All the 33 positions have been declared as static constants in PoseLandmark class
remoteModelManager() → RemoteModelManager
returns an instance of RemoteModelManager.
textDetector() → TextDetector
Return an instance of TextDetector.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance → Vision
final

Constants

channel → const MethodChannel